@@ -6,5 +6,5 @@
 
 document.addEventListener("DOMContentLoaded", function () {
     var fileUri = document.getElementById("pdf-file-uri").value;
-    PDFView.open(fileUri);
+    window.PDFView.open(fileUri);
 });
